%load_melt_fraction_for_subNeptune_magma_ocean
%Edwin Kite
%Calculate the approximate fraction of a sub-Neptune's magma ocean that is molten.
%Neglected: Effect of the pressure of the envelope on the solidus location.
%Density contrast between melt and solid.

%WARNING: Linear extrapolation of pressure on the 'a11_P2 = interp1' line makes this
%code unusable for any but the exact purpose it is set up for!

%Not yet included: Pyrolite, Miyazaki & Korenaga 2019 JGR Solid Earth (part 2)
%Useful review: %Andrault et al. 2017 PEPI

%load PREM
%radius,depth,density,Vpv,Vph,Vsv,Vsh,eta,Q-mu,Q-kappa
mearth = 5.972e24;
depthsample_km = [0:10:5000];

prem = csvread('PREM_1s.csv');
prem = prem(1:159,:); %truncate at Earth's CMB

atmosphere_pressure_list = [0 1e10]; %Pa


for mpl = 1:20 %Earths; only considering core
    minwards(mpl,1) = mearth * mpl;
    rpl_Earths = mpl^0.27;
    P(mpl,1) = 0;
    for l = 2:size(prem,1) %Explore down to one Earth mantle DEPTH within rocky-core mantles.
        if mpl == 1;
            density(mpl,l) = prem(l,3);
        else
            density(mpl,l) = interp1(P(1,:)+[1:size(P,2)],prem(:,3),P(mpl,l-1),'linear','extrap');
        end
        
        deltam(mpl,l) = 4*pi*(prem(l,1)*rpl_Earths*1e3).^2*1e3.*(prem(l,2)-prem(l-1,2))*density(mpl,l)*1e3;
        minwards(mpl,l) = minwards(mpl,l-1) - deltam(mpl,l);
        g(mpl,l) = 6.67e-11*minwards(mpl,l)./((prem(l,1)*rpl_Earths*1e3).^2);
        
        P(mpl,l) = P(mpl,l-1) + g(mpl,l)*1e3.*(prem(l,2)-prem(l-1,2))*density(mpl,l)*1e3;
        Vinwards(mpl,l) = ((prem(1,1)*rpl_Earths-prem(l,2))./(prem(1,1)*rpl_Earths))^3;
        moutwards(mpl,l) = mearth*mpl - minwards(mpl,l);
    end
end

figure;plot(P',moutwards'./6e24);xlabel('Pressure (Pa)');ylabel('Mass at less than this pressure (Earths)');grid on

%Implemented:
%Andrault et al. 2011 EPSL <-- chondritic, significantly lower
%solidus/liquidus than pyrolite of Korenaga
%WebPlotDigitizer points are in order solidus, liquidus, 3000K
%potential-temperature adiabat, 2800K adiabat, 2400K adiabat, 2200K adiabat
a = csvread('Andrault_et_al_EPSL_2011_Figure_5.csv');

%Interpolate onto a regular grid of melt fraction as a function of
%potential temperature and pressure in GPa
a11_solidus_z = a(1:13,1); a11_solidus_T = a(1:13,2); 
a11_z2 = depthsample_km;
a11_solidus_T2 = interp1(a11_solidus_z,a11_solidus_T,a11_z2,'linear','extrap');
a11_liquidus_z = a(14:26,1); a11_liquidus_T = a(14:26,2);
a11_liquidus_T2 = interp1(a11_liquidus_z,a11_liquidus_T,a11_z2,'linear','extrap');
a11_P2 = interp1(prem(:,2)'+[1:159]*1e-3,P(1,:)',a11_z2,'linear','extrap'); %Output is in Pa. uses PREM

Tp_list = [3e3:-2e2:2.2e3]; %potential temperatures,K
ad_raw(1,:,:) = a(27:43,:); %raw adiabats
ad_raw(2,1:13,:) = a(44:56,:);
ad_raw(3,1:8,:) = a(57:64,:);
ad_raw(4,1:9,:) = a(65:73,:);
ad_raw(5,1:7,:) = a(74:80,:);
ad_raw(ad_raw==0) = NaN;

for l = 1:size(ad_raw,1)
    ad_raw(l,:,3) = Tp_list(l);

zraw = reshape(ad_raw(l,:,1),[],1);
Traw = reshape(ad_raw(l,:,2),[],1);
Tpraw = reshape(ad_raw(l,:,3),[],1);

Tpraw(isnan(zraw)) = []; Traw(isnan(zraw)) = [];
zraw(isnan(zraw)) = [];

adiabats(l,:) = interp1(zraw,Traw,depthsample_km,'linear','extrap');
end

[xq,yq] = meshgrid([0:10:4e3],depthsample_km);

andrault2011_mf_vs_depth = griddata([0;10e3;a11_z2';a11_z2';0;10e3],...
    [0;0;a11_solidus_T2';a11_liquidus_T2';2e4;2e4], ...
[0;0;a11_z2'.*0;a11_z2'.*0+1;1;1],xq,yq);

figure;plot(depthsample_km/10,adiabats')
hold on
contour([0:1:400],depthsample_km,andrault2011_mf_vs_depth)


%Find the mass in kg of melt by intersecting each adiabat with each solidus
for api = 1:length(atmosphere_pressure_list) %atmosphere pressure index
                    atmosphere_pressure = atmosphere_pressure_list(api)
for mpl = 1:20 %Earths; only considering core
    for adi = 1:size(adiabats,1) %adiabat index
                melt_outwards(mpl,adi,1) = 0; total_mass(mpl,adi,1) = 0;
                local_melt_fraction(mpl,adi,1) = 1;
            for l = 2:size(prem,1) %Explore down to one Earth mantle DEPTH within rocky-core mantles.
                    equivalent_depth_on_Earth(mpl,l) = interp1(a11_P2,a11_z2,P(mpl,l)+atmosphere_pressure);
                    above_liquidus(mpl,adi,l) = interp1(depthsample_km,adiabats(adi,:)-a11_liquidus_T2,equivalent_depth_on_Earth(mpl,l));
                    above_solidus(mpl,adi,l) =  interp1(depthsample_km,adiabats(adi,:)-a11_solidus_T2, equivalent_depth_on_Earth(mpl,l));

                    if above_solidus(mpl,adi,l)<0
                        local_melt_fraction(mpl,adi,l) = 0;
                    elseif above_liquidus(mpl,adi,l)>0
                        local_melt_fraction(mpl,adi,l) = 1;
                    else
                        local_melt_fraction(mpl,adi,l) = above_solidus(mpl,adi,l)./sum(abs(above_solidus(mpl,adi,l))+abs(above_liquidus(mpl,adi,l)));
                    end
                    melt_outwards(mpl,adi,l) = melt_outwards(mpl,adi,l-1) ...
                        + deltam(mpl,l) .* local_melt_fraction(mpl,adi,l);

                    total_mass(mpl,adi,l) = total_mass(mpl,adi,l-1) + deltam(mpl,l).*(1-isnan(local_melt_fraction(mpl,adi,l))); 
                end
            end
    end


if atmosphere_pressure == 0 %no-overburden case: to be shown in figures
    minimum_melt_fraction = nanmin(local_melt_fraction,[],3); %if it is nonzero, there is some melt at 2900km depth
    total_melt_mass_shallower_than_2900km = max(melt_outwards,[],3); %kg
end
    minimum_melt_fraction_atm(api,:,:) = nanmin(local_melt_fraction,[],3); %if it is nonzero, there is some melt at 2900km depth
    total_melt_mass_shallower_than_2900km_atm(api,:,:) = max(melt_outwards,[],3); %kg

end

surf(nanmin(local_melt_fraction,[],3))
surf(max(melt_outwards,[],3))
figure
surf(max(melt_outwards,[],3)./max(total_mass,[],3))


save results_of_load_melt_fraction_for_subNeptune_magma_ocean minimum_melt_fraction total_melt_mass_shallower_than_2900km Tp_list