%parse_fugacity_for_origin_of_the_volatile_envelopes_of_small_radius_exoplanets_v3
%Edwin Kite
%Purpose: Explain the 3-Earth-radius cliff in the planet radius histogram.
%Restrictions: Only integer-Earth-mass planet masses are allowed. Ceiling:
%20 MEarth. Only specific silicate-atmosphere interface temperatures are permitted (2000K, 2500K, and 3000K).

load results_of_parse_eos_small_radius_exoplanets_for_fugacity_crisis_processed ...
        mass_atm Mcore_list boep_list Tinit_list boaT %mass_atm in kg, Mcore in MEarths; boep (base of atm pressure) in Pa; Tinit_list is the temperature at the radiative-convective boundary (in K), boet: bottom-of-atmosphere temperature (in K)

if exist('offsetter','var') == 0; offsetter = 10; end %for figures

Tmai = 3000; %temperature at bottom of atmosphere, assumed equal to temperature at top of magma (in reality, they will differ).
h2supply_option = 'loggaussian';%'loggaussian'%'loguniform';%'loguniform'
max_h2_percent_loggaussian = 50; %max H2 supply from nebula, % of core mass
max_h2_mf_in_melt = 0.40;%0.40;%0.5; %maximum H2 mass fraction in melt 
To = 4000;%4000; %For cross-checking with Chachan & Stevenson ApJ 2018. This is an Arrhenius factor for solubility, and not an actual temperature at an interface.
melt_fraction = 1.0; %Alter this from 1.0 only for sensitivity tests; melt fraction is now calculated self-consistently.
solubility_enhancement_factor = 1.0; %Alter this from 1.0 only for sensitivity tests

%from Table 3 of Fulton et al. AJ 2017 - Earth radii. The actual data
%plotted are from Fulton & Petigura 2018. I have verified that bin
%locations are correct.
bin_edges = [1.16,1.29,1.43,1.59,1.77,1.97, 2.19, 2.43, 2.70, ...
    3.00, 3.33, 3.70, 4.12, 4.57, 5.08, 5.65, 6.27, 6.97, 7.75, 8.61, ...
    9.56, 10.63, 11.81, 13.12, 14.58, 16.20, 18.00];
bin_densify = 1; %Set to 1 for straight comparison to Fulton & Petigura 2018. Set to higher integer values to check code output.

    bin_edges_new = [];
for l = 1:(length(bin_edges)-1)
    bin_edges_append = linspace(bin_edges(l),bin_edges(l+1),bin_densify+1);
    bin_edges_append(end) = [];
    bin_edges_new = [bin_edges_new,bin_edges_append];
end
    bin_edges = bin_edges_new;

load_fulton_and_petigura_2018

load_fugacity_coefficients_supplied_by_fegley

load_lopez_fortney_2014 %Radius as a function of envelope mass, core mass, solar luminosity, and age.

Earth_mantle_mass = 4.0e24; %kg
whole_Earth_mass = 6.0e24; %kg
A_Earth = 5.1e14; %m^2
g_Earth = 9.8;  %m/s^2
npl = 3e5; %number of planets for Monte Carlo procedure

%From Hirschmann et al. EPSL 2012: %"Calculated solubilities for [peridotite melts], 
%extrapolated based on the diminished ionic porosity of ultramafic liquids, 
%are smaller than for basalt by about a factor of 3 (Fig. 5), such that at
%1 GPa in the presence of pure H2, the molecular H2 concentration is 0.19 wt."%.
A = 0.0019./((10.^5).*1e4.*exp(-To./1673)); %differs from Chachan & Stevenson

%Later we will multiply by phi(T,P), so for self-consistency we divide the
%calibration point by phi(T,P)
phiH2_to_normalize_H12_correctly = interp1(dense_p(14,1:end-1),SCVH_f_H2_1673,1e9);

A = A./phiH2_to_normalize_H12_correctly;     

sH2 = solubility_enhancement_factor.*A.*(1e5).*exp(-To./Tmai); %A hypothetical T-dependence of the *fugacity* dependent solubility.

load results_of_load_melt_fraction_for_subNeptune_magma_ocean ...
    minimum_melt_fraction total_melt_mass_shallower_than_2900km Tp_list


  if Tmai == 2000
    fP = dense_p(15,1:end-1); fH = SCVH_f_H2_2000;
  elseif Tmai == 2500
    fP = dense_p(16,1:end-1); fH = SCVH_f_H2_2500;  
  elseif Tmai == 3000
    fP = dense_p(17,1:end-1); fH = SCVH_f_H2_3000;
  end

show_fugacity_crisis_supporting_figures_v2

%show Hsu et al. 2019 data (marginalized over periods < 64 days, from Danley Hsu, via email)
f = [0.5	0.75	0.432069698	0.407136363	0.226722872
0.75	1	0.228971338	0.096292891	0.079034703
1	1.25	0.157675885	0.064814394	0.058013085
1.25	1.5	0.101827869	0.055257751	0.031272045
1.5	1.75	0.076921064	0.036573635	0.028155237
1.75	2	0.051715857	0.028688787	0.026291249
2	2.5	0.148127139	0.039853262	0.033068586
2.5	3	0.143656626	0.030092237	0.027803817
3	4	0.05359089	0.021573058	0.017574832
4	6	0.015379457	0.01057668	0.008798601
6	8	0.01007368	0.006571747	0.00497885
8	12	0.008909774	0.007077734	0.004625534
12	16	0.013104169	0.006891023	0.005088867];

figure(2+offsetter);
adjusted_sum_over_periods = f(:,3)./(f(:,2)-f(:,1));
adjusted_ul_over_periods = ((f(:,3)+f(:,4))./(f(:,2)-f(:,1)))./(2.25*(sum(adjusted_sum_over_periods(7:11))));
adjusted_ll_over_periods = ((f(:,3)-f(:,5))./(f(:,2)-f(:,1)))./(2.25*(sum(adjusted_sum_over_periods(7:11))));
adjusted_he_over_periods = f(:,4)./(f(:,2)-f(:,1));
adjusted_le_over_periods = f(:,5)./(f(:,2)-f(:,1));
 patch([(f(:,1)+f(:,2))/2; flipud((f(:,1)+f(:,2))/2)] ,[adjusted_ul_over_periods; flipud(adjusted_ll_over_periods)],[.6 .6 .6],'facealpha',0.45,'edgecolor','none')
 hold on

 xlim([1.4 10])
 for showf=[3,9]
figure(showf+offsetter);
 patch([(f(:,1)+f(:,2))/2; flipud((f(:,1)+f(:,2))/2)] ,[adjusted_ul_over_periods; flipud(adjusted_ll_over_periods)],[.6 .6 .6],'facealpha',0.45,'edgecolor','none')
 hold on
  set(gca,'tickdir','out')
 end
 
fp18_fromfulton(isnan(fp18_fromfulton))=0
for showf = [2,3,9]
    figure(showf+offsetter); %show Fulton & Petigura data
patch([fp18_fromfulton(:,1); flipud(fp18_fromfulton(:,1))] ,...
    [(fp18_fromfulton(:,2)+fp18_fromfulton(:,3))./sum(fp18_fromfulton(6:16,2)); ...
    flipud((fp18_fromfulton(:,2)-fp18_fromfulton(:,3))./sum(fp18_fromfulton(6:16,2)))],[.3 .3 .3],'facealpha',0.6,'edgecolor','none')
hold on
end

figure(9+offsetter); %show Fulton & Petigura data
line([3.16 3.16], [0 0.25],'color','k','linestyle','--')


for sensitivity_test = 1:3
    
if sensitivity_test == 1; 
    mplEarths = 4; radii = squeeze(lopezfortney2014_table2_dense(5, find(mplEarths==lopezfortney2014_dense_masses), :));
    linestyle = '-';
elseif sensitivity_test == 2
    mplEarths = 5; radii = squeeze(lopezfortney2014_table2_dense(5, find(mplEarths==lopezfortney2014_dense_masses), :));
 linestyle = '--';
elseif sensitivity_test == 99
    mplEarths = 8; radii = squeeze(lopezfortney2014_table2_dense(5, find(mplEarths==lopezfortney2014_dense_masses), :));
 linestyle = ':';
elseif sensitivity_test == 99
     mplEarths = 6; radii = squeeze(lopezfortney2014_table2_dense(4, find(mplEarths==lopezfortney2014_dense_masses), :));
  linestyle = '--';
elseif sensitivity_test == 99
    mplEarths = 6; radii = squeeze(lopezfortney2014_table2_dense(4, find(mplEarths==lopezfortney2014_dense_masses), :));
 linestyle = ':';
elseif sensitivity_test == 3
    mplEarths = 6; radii = squeeze(lopezfortney2014_table2_dense(5, find(mplEarths==lopezfortney2014_dense_masses), :));
 linestyle = '-.';
end

    if interp1(Tp_list,minimum_melt_fraction(mplEarths,:),Tmai,'linear','extrap') >= 0.999; %Molten to highest pressure considered
        melt_mass = Earth_mantle_mass*mplEarths*melt_fraction; %Assume mantle is still molten at still greater depths.
        plot_sensitivity_to_no_crystals = 0
    else 
        melt_mass = max(0,interp1(Tp_list,total_melt_mass_shallower_than_2900km(mplEarths,:),Tmai,'linear','extrap'));
        plot_sensitivity_to_no_crystals = 1
    end

    g = (g_Earth.*mplEarths./((mplEarths^0.27).^2)); %assuming Rpl \propto (mplEarths)^0.27 (Valencia et al. 2006)
  Apl = A_Earth*(mplEarths^0.27)^2; %area of the top of the magma ocean in m^2

  
  
 h2_in_mantle =  min(max_h2_mf_in_melt, ...
     sH2.*fP./1e5.*fH) ...
      *melt_mass; %    *Earth_mantle_mass*mplEarths*melt_fraction;

 h2_in_mantle_constant_fc =  min(max_h2_mf_in_melt,sH2.*fP./1e5) ...
      *melt_mass;  %    *Earth_mantle_mass*mplEarths*melt_fraction;

 
 TRCB_for_interp  = ... %The parse_eos script gives atmosphere mass as a function of RCB temperature.      %We need to relate this to the core-atmosphere interface temperature.
 griddata(boaT,repmat(boep_list,4,[]),repmat(Tinit_list,100,1)',...
 repmat(Tmai,4999,1)',fP);
 
 [x1,y1,z1] = meshgrid(Tinit_list,[1:max(Mcore_list)],boep_list);

 h2_in_atmosphere_constant_g = fP./g*Apl;
 h2_in_atmosphere = interp3(x1,y1,z1, ...
     mass_atm, ...
     TRCB_for_interp,repmat(mplEarths,1,4999),fP,'makima');
 %The parse_eos output has a minimum P of ~100 bars (RCB pressure). Need to
 %interpolate for thinner atmospheres.
 h2_in_atmosphere(1:min(find(isnan(h2_in_atmosphere)==0))) = ...
   h2_in_atmosphere(min(find(isnan(h2_in_atmosphere)==0))).* ... %Constant gravity for small Patm
   fP(1:min(find(isnan(h2_in_atmosphere)==0)))./fP(min(find(isnan(h2_in_atmosphere)==0)));
%Very thick atmospheres: log-linear extrapolation
 h2_in_atmosphere(isnan(h2_in_atmosphere)) = ...
10.^interp1(log10(fP(~isnan(h2_in_atmosphere))),log10(h2_in_atmosphere(~isnan(h2_in_atmosphere))), ...
            log10(fP(isnan(h2_in_atmosphere))),'linear','extrap');

 total_h2 = h2_in_mantle + h2_in_atmosphere;
 
 total_h2_no_crystals = ( min(max_h2_mf_in_melt, sH2.*fP./1e5.*fH...
     *Earth_mantle_mass*mplEarths*melt_fraction ) + h2_in_atmosphere);
 
 total_h2_constant_fc = h2_in_mantle_constant_fc + h2_in_atmosphere;
 
 total_h2_constant_fc_no_crystals = ( min(max_h2_mf_in_melt,sH2.*fP./1e5 ...
     *Earth_mantle_mass*mplEarths*melt_fraction ) + h2_in_atmosphere);
 

 figure(1+offsetter);title('Fugacity crisis')
 hold on
 plot(total_h2./(whole_Earth_mass*mplEarths),h2_in_atmosphere./(whole_Earth_mass*mplEarths),'linestyle',linestyle,'linewidth',3,'color','r');
 %Sensitivity to 'no crystallisation':
 henrian_x = total_h2_constant_fc./(whole_Earth_mass*mplEarths);
 henrian_y = h2_in_atmosphere./(whole_Earth_mass*mplEarths);
 plot([0:0.01:0.1],interp1(henrian_x(~isnan(henrian_x)),henrian_y(~isnan(henrian_y)),[0:0.01:0.1],'linear','extrap'),'linestyle',linestyle,'linewidth',3,'color','b');
 set(gca,'tickdir','out')
 ax = gca;
ax.TickLength = [.03, .03];

 if plot_sensitivity_to_no_crystals == 1
    plot(total_h2_no_crystals./(whole_Earth_mass*mplEarths),h2_in_atmosphere./(whole_Earth_mass*mplEarths),'linestyle',linestyle,'linewidth',1,'color','b');
    henrian_x = total_h2_constant_fc_no_crystals./(whole_Earth_mass*mplEarths);
    henrian_y = (Apl*fP*1e3*1e5/g)./(whole_Earth_mass*mplEarths);
    plot([0:0.01:0.1],interp1(henrian_x(~isnan(henrian_x)),henrian_y(~isnan(henrian_y)),[0:0.01:0.1],'linear','extrap'),'linestyle',linestyle,'linewidth',1,'color','b');
 end
 
 %Map onto radius distribution:

%log-uniform distribution of H2 supply
switch h2supply_option
    case 'loguniform' %in percent of core mass
        h2added_percent = logspace(log10(0.1),log10(30),npl);%percentage by mass, log-uniform dist'n. 30 for comparison with OwenWuApJ2017, 50 default
    case 'uniform' %in percent of core massf
        h2added_percent = linspace((0.1),(30),npl);%percentage by mass, uniform dist'n
    case 'loggaussian' % in percent of core mass
        h2added_percent = 10.^(randn(npl,1)+log10(5));
        h2added_percent(h2added_percent>max_h2_percent_loggaussian) = NaN;
end

radii_impermeable(h2added_percent<max(env_mass_percent)) = interp1(env_mass_percent,radii, ...
    h2added_percent(h2added_percent<max(env_mass_percent)),'linear');
radii_impermeable(h2added_percent>max(env_mass_percent)) = interp1(env_mass_percent,radii, ...
    h2added_percent(h2added_percent>max(env_mass_percent)),'linear','extrap');

ok = (find(~isnan(total_h2)));
env_percentage_with_fugacity = interp1( ...
    100*total_h2(~isnan(total_h2))./(whole_Earth_mass*mplEarths),...
    100*h2_in_atmosphere(~isnan(h2_in_atmosphere))./(whole_Earth_mass*mplEarths),h2added_percent,'linear','extrap');

radii_with_fugacity(env_percentage_with_fugacity<max(env_mass_percent)) = interp1(env_mass_percent,radii, ...
    env_percentage_with_fugacity(env_percentage_with_fugacity<max(env_mass_percent)),'pchip');
radii_with_fugacity(env_percentage_with_fugacity>max(env_mass_percent)) = interp1(env_mass_percent,radii, ...
    env_percentage_with_fugacity(env_percentage_with_fugacity>max(env_mass_percent)),'linear','extrap');

%Temperature-dependent, Henrian-by-pressure solubility
h2_in_env_henrian = interp1( ... %Chachan and Stevenson 2018
    100*total_h2_constant_fc(~isnan(total_h2_constant_fc))./(whole_Earth_mass*mplEarths),...
    100*h2_in_atmosphere(~isnan(h2_in_atmosphere))./(whole_Earth_mass*mplEarths),h2added_percent,'linear','extrap');

radii_constant_fc(h2_in_env_henrian<max(env_mass_percent)) = ...
    interp1(env_mass_percent,radii, h2_in_env_henrian(h2_in_env_henrian<max(env_mass_percent)), 'pchip');
radii_constant_fc(h2_in_env_henrian>max(env_mass_percent)) = ...
    interp1(env_mass_percent,radii,h2_in_env_henrian(h2_in_env_henrian>max(env_mass_percent)),'linear','extrap');

figure(2+offsetter);
    normalization = (1./bin_densify).*sum(radii_impermeable<bin_edges(17*bin_densify - (bin_densify-1)) & radii_impermeable>bin_edges(6*bin_densify - (bin_densify-1)))
    plot(bin_edges*1.06,histc(radii_impermeable,bin_edges)./normalization,'linestyle',linestyle,'color','k','linewidth',2)
    hold on
    normalization = (1./bin_densify).*sum(radii_with_fugacity<bin_edges(17*bin_densify - (bin_densify-1)) & radii_with_fugacity>bin_edges(6*bin_densify - (bin_densify-1)))
    plot(bin_edges*1.06,histc(radii_with_fugacity,bin_edges)./normalization,'linestyle',linestyle,'color','r','linewidth',2)
    normalization = (1./bin_densify).*sum(radii_constant_fc<bin_edges(17*bin_densify - (bin_densify-1)) & radii_constant_fc>bin_edges(6*bin_densify - (bin_densify-1)))
    plot(bin_edges*1.06,histc(radii_constant_fc,bin_edges)./normalization,'linestyle',linestyle,'color','b','linewidth',2)
    xlabel('Radius (Earth radii)');ylabel({'Fraction of planets';'(in range 2 R_{Earth} < R < 6.3 R_{Earth})'})
    xlim([1.4 10])
    scatter(mplEarths^0.27,0.005,200,'k','v','filled')    
    set(gca,'xscale','log');  set(gca,'tickdir','out')
    box on
    
    interpolatethis = fP;
    interpolatethis = interpolatethis(~isnan(interpolatethis));
    env_mass_percent_10kbar = interp1(interpolatethis,100*h2_in_atmosphere(1:length(interpolatethis))./(whole_Earth_mass*mplEarths),10*1e8);
    env_mass_percent_80kbar = interp1(interpolatethis,100*h2_in_atmosphere(1:length(interpolatethis))./(whole_Earth_mass*mplEarths),80*1e8);
    
    radius_10kbar = interp1(env_mass_percent,radii,env_mass_percent_10kbar)
        normalization = (1./bin_densify).*sum(radii_with_fugacity<bin_edges(17*bin_densify - (bin_densify-1)) & radii_with_fugacity>bin_edges(6*bin_densify - (bin_densify-1)))
    scatter(radius_10kbar, ...
        interp1(bin_edges*1.06,histc(radii_with_fugacity,bin_edges)./normalization,radius_10kbar),200,'r*')
    radius_80kbar = interp1(env_mass_percent,radii,env_mass_percent_80kbar) 
    scatter(radius_80kbar, ...
        interp1(bin_edges*1.06,histc(radii_with_fugacity,bin_edges)./normalization,radius_80kbar),200,'ro')
    grid off;set(gcf,'color','white');set(gca,'fontsize',15)
    set(gca,'xtick',[1.4 2 3 4 6 8 10 12])
    
    figure(1+offsetter);
    ok = ~isnan(total_h2./(whole_Earth_mass*mplEarths));
    scatter(interp1(h2_in_atmosphere(ok)./(whole_Earth_mass*mplEarths),total_h2(ok)./(whole_Earth_mass*mplEarths),0.01*env_mass_percent_10kbar),0.01*env_mass_percent_10kbar,200,'r*')
    scatter(interp1(h2_in_atmosphere(ok)./(whole_Earth_mass*mplEarths),total_h2(ok)./(whole_Earth_mass*mplEarths),0.01*env_mass_percent_80kbar),0.01*env_mass_percent_80kbar,200,'ro')

rstore(sensitivity_test,1:length(radii_with_fugacity)) = radii_with_fugacity;
rstore_impermeable(sensitivity_test,1:length(radii_impermeable)) = radii_impermeable;
rstore_constant_fc(sensitivity_test,1:length(radii_constant_fc)) = radii_constant_fc;

    figure(3+offsetter)
        scatter(mplEarths^0.27,0.005,200,'k','v','filled')    
hold on
end

rstore = reshape(rstore,[],1); rstore_impermeable = reshape(rstore_impermeable,[],1); rstore_constant_fc = reshape(rstore_constant_fc,[],1);

figure(3+offsetter)
    normalization = (1./bin_densify).*sum(rstore<bin_edges(17*bin_densify - (bin_densify-1)) & rstore>bin_edges(6*bin_densify - (bin_densify-1)));
    plot(bin_edges*1.06,histc(rstore,bin_edges)./normalization,'linestyle','-','color','r','linewidth',3)
hold on
    normalization = (1./bin_densify).*sum(rstore_impermeable<bin_edges(17*bin_densify - (bin_densify-1)) & rstore_impermeable>bin_edges(6*bin_densify - (bin_densify-1)));
    plot(bin_edges*1.06,histc(rstore_impermeable,bin_edges)./normalization,'linestyle','-','color','k','linewidth',3)
    normalization = (1./bin_densify).*sum(rstore_constant_fc<bin_edges(17*bin_densify - (bin_densify-1)) & rstore_constant_fc>bin_edges(6*bin_densify - (bin_densify-1)));
    plot(bin_edges*1.06,histc(rstore_constant_fc,bin_edges)./normalization,'linestyle','-','color','b','linewidth',3)
    xlim([1.4 10])
    set(gca,'xscale','log');  set(gca,'tickdir','out')
    box on
line([3.16 3.16],[0 0.5],'linestyle','--','color','k')
ax = gca;
ax.TickLength = [.03, .03];
set(gcf,'color','white');set(gca,'fontsize',15)
    xlabel('Radius (Earth radii)');ylabel({'Fraction of planets';'(in range 2 R_{Earth} < R < 6.3 R_{Earth})'})


    figure(2+offsetter)
line([3.16 3.16],[0 0.5],'linestyle','--','color','k')
ax = gca;
ax.TickLength = [.03, .03];

